@@ -44,7 +44,7 @@ class MutationBuilder():
     _mutation: str = ''
     _children: dict = field(default_factory=dict)
     _isChild: bool = False
-    _gql: GraphQLClient = field(default_factory=setup_gql)
+    _gql: GraphQLClient = field(default=setup_gql())
     # New parameter that tells the mutation builder which kind
     # of mutation it's going to create, seems useful since we're adding mutations other than create.
     Type: MutationType = MutationType.CREATE
