@@ -30,17 +30,17 @@ def default_map(var_type, variable):
     elif var_type == 'Float':
         return ("float", float(variable))
     elif var_type == 'Date':
-        return ('date', f'get_datetime_object({variable}, "{var_type}")')
+        return ('date', f'get_datetime_object("{variable}", "{var_type}")')
     elif var_type == 'Time':
         return ('time', f'get_datetime_object({variable}, "{var_type}")')
     elif var_type == 'DateTime':
         return ('datetime', f'get_datetime_object({variable}, "{var_type}")')
     elif var_type == "Boolean":
-        return ("bool", variable.capitalize())
+        return ("bool", variable)
     elif var_type == "map":
         return ("dict", variable)
     elif var_type == "String":
-        return ("str", variable)
+        return ("str", f"'{variable}'")
     else:  # Enum
         return (var_type, variable)
 
